@@ -1,15 +1,18 @@
 # This should not be used by user, but is used by ipyslides to generate layout of slides
 
 from ..utils import _build_css
+from ..xmd import get_unique_css_class
 from .icons import Icon
 
 _zoom_ables = '.jp-RenderedImage > img, .zoom-self, .zoom-child > *:not(.no-zoom), .plot-container.plotly'
 _icons_size = '1em' # For all except Chevrons
 
 def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult is off
-    return _build_css((),{
+    uclass = get_unique_css_class()
+    return _build_css((uclass,),{
         'a.jp-InternalAnchorLink': {'display': 'none !important'},
-        '.SlidesWrapper': {
+        '^.SlidesWrapper': {
+            'container': 'slides / inline-size',
             'z-index': '1 !important',
             '^.SingleSlide .Controls': {'display':'none !important',}, 
             '^.CaptureMode': {
@@ -46,13 +49,28 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 'text-shadow': '0 0 4px white, 0 0 8px var(--secondary-bg)',
                 'border-radius':'50%',
             },
+            'div.LaserPointer': { # For laser pointer 
+                'position':'absolute !important',
+                'width':'12px',
+                'height':'12px',
+                'left':'-50px', # Hides when not required , otherwise handled by javascript*/
+                'z-index':'9', # below side panel but above zoomed image */
+                'border-radius':'50%',
+                'border':' 2px solid white',
+                'background':' var(--pointer-color)',
+                'box-shadow':' 0 0 4px 2px white, 0 0 6px 6px var(--pointer-color)',
+                'display':'none', # Initial setup. Display will be set using javascript only */
+                'overflow':'hidden !important', # To hide at edges */
+                'opacity': f'{1 if show_laser_pointer else 0} !important',
+            },
             '.SlideArea': {
-                'align-items': 'center',
-                f'@media screen and (max-width: {breakpoint})': {
-                'min-width' : '100% !important', # can't work without min-width
-                'width':'100% !important', 
-                'padding-bottom': '50px !important',
-                },
+                'justify-content': 'center',
+                f'@media screen and (max-width: {breakpoint})': (_breakpoint_css := {
+                    'min-width' : '100% !important', # can't work without min-width
+                    'width':'100% !important', 
+                    'padding-bottom': '50px !important',
+                }),
+                '@container slides (max-width: 650px)': _breakpoint_css,
                 '.report-only': {
                     'display': 'none !important'
                 },
@@ -123,7 +141,8 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 'left': '0px !important',
                 'height': '100% !important',
                 'box-shadow': '0 0 4px 4px var(--secondary-bg)',
-                f'@media screen and (max-width: {breakpoint})': {'width': '100% !important'},
+                f'@media screen and (max-width: {breakpoint})': (_breakpoint_css := {'width': '100% !important'}),
+                '@container slides (max-width: 650px)': _breakpoint_css,
                 '.CaptureHtml' : {
                     'border': '1px solid var(--secondary-fg)',
                     'figure' : {
@@ -185,31 +204,52 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 },
             },
         },
-        'div.LaserPointer': { # For laser pointer 
-            'position':'absolute !important',
-            'width':'12px',
-            'height':'12px',
-            'left':'-50px', # Hides when not required , otherwise handled by javascript*/
-            'z-index':'9', # below side panel but above zoomed image */
-            'border-radius':'50%',
-            'border':' 2px solid white',
-            'background':' var(--pointer-color)',
-            'box-shadow':' 0 0 4px 2px white, 0 0 6px 6px var(--pointer-color)',
-            'display':'none', # Initial setup. Display will be set using javascript only */
-            'overflow':'hidden !important', # To hide at edges */
-            'opacity': f'{1 if show_laser_pointer else 0} !important',
-        },
         '.NavWrapper': {
             'max-width': '100% !important',
+            '^,^ > div': {
+                'padding': '0px',
+                'margin': '0px',
+                'overflow': 'hidden',
+                'max-width': '100%',
+            },
             '.progress': {
+                'width': '100% !important',
+                'transform': 'translate(-2px,1px) !important',
                 'background': 'var(--secondary-bg) !important',
                 '.progress-bar': { 'background': 'var(--accent-color) !important' },
+                '^, .progress-bar': {
+                    'border-radius': '0px',
+                    'margin': '0px',
+                    'padding': '0px',
+                    'height': '4px !important',
+                    'overflow': 'hidden',
+                    'left': '0px',
+                    'bottom': '0px',
+                },
+            },
+            '.widget-hprogress': {
+                'height': '4px !important',
             },
             '.NavBox': {
+                'z-index': '2',
+                'overflow': 'hidden',
                 'align-items': 'center',
                 'height':'max-content',
                 'justify-content': 'flex-start', 
+                '.Menu-Item': {
+                    'font-size': '18px !important',
+                    'overflow': 'hidden',
+                    'opacity': '0.4',
+                    'z-index': '3',
+                    '^:hover': {
+                        'opacity': '1',
+                    },
+                },
                 '.Toc-Btn': {'min-width':'40px',}, # Avoid overflow in small screens
+                '.Footer': {
+                    '.widget-html-content': {'display': 'flex', 'align-items': 'center', 'justify-content': 'flex-start',},
+                    'p': {'font-size': '14px !important',},
+                },
             },
         },
         '.FloatControl': {
@@ -240,13 +280,14 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             'align-items':'center !important',
             'margin-bottom':'16px !important',
             'color':' var(--accent-color) !important',
-            f'@media screen and (max-width: {breakpoint})': {
+            f'@media screen and (max-width: {breakpoint})': (_breakpoint_css := {
                     'bottom': '30px !important',
                     'right': '0 !important',
                     'width' : '100% !important',
                     'justify-content': 'space-around !important',
                     'button' : {'width': '30% !important'},
-            },
+            }),
+            '@container slides (max-width: 650px)': _breakpoint_css,
             '.widget-button > i': { 'color': 'var(--accent-color) !important',},
             '.Arrows': {
                 'opacity':'0.4',
@@ -266,7 +307,8 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                     'justify-content': 'center',
                     'opacity': 1,
                 },
-                f'@media screen and (max-width: {breakpoint})': {'width': '40%', 'opacity': 0,},
+                f'@media screen and (max-width: {breakpoint})': (_breakpoint_css := {'width': '40%', 'opacity': 0,}),
+                '@container slides (max-width: 650px)': _breakpoint_css,
             },
         },
         
@@ -281,7 +323,8 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             'z-index':' 8',
             'border-radius':' 4px',
             'border':' 1px solid var(--hover-bg)',
-            f'@media screen and (max-width: {breakpoint})': {'min-width': 'calc(100% - 72px) !important'},
+            f'@media screen and (max-width: {breakpoint})': (_breakpoint_css := {'min-width': 'calc(100% - 72px) !important'}),
+            '@container slides (max-width: 650px)': _breakpoint_css,
             '.goto-box': {
                 'justify-content': 'space-between',
                 'height': 'auto',
@@ -356,7 +399,8 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             '^:hover, ^:focus': {
                 'min-height': '32px !important',
                 'width': '60% !important',
-                f'@media screen and (max-width: {breakpoint})': {'width': 'calc(100% - 16px) !important'}, # There is 8px margin
+                f'@media screen and (max-width: {breakpoint})': (_breakpoint_css :={'width': 'calc(100% - 16px) !important'}), # There is 8px margin
+                '@container slides (max-width: 650px)': _breakpoint_css,
                 '> .Settings-Btn' : {
                     'width': 'auto !important',
                     'opacity': '1 !important',
@@ -371,7 +415,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             '> *:not(.Settings-Btn)' : {'display': 'none !important'},
             '^:hover > *:not(:disabled), ^:focus > *:not(:disabled)': { 'display': 'unset !important'},
         },
-        '.Inline-Notes': {
+        '<.Inline-Notes': {
             'background': 'var(--primary-bg)',
             'color': 'var(--primary-fg)',
             'border': '1px solid var(--accent-color)',
@@ -385,7 +429,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 'padding':'4px',
             },
         },
-        '.jp-OutputArea-child': {
+        '<.jp-OutputArea-child': {
             '^, .jp-OutputArea-output': { # For some themes
                 'background': 'transparent !important',
                 'background-color': 'transparent !important', 
@@ -513,7 +557,7 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
                 'width': '100% !important',
             },
         }, # @media print
-        'body[data-base-url]': { #Voila
+        '<body[data-base-url]': { #Voila
             'position': 'fixed !important',
             'top': '0 !important',
             'left': '0 !important',
@@ -547,35 +591,45 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
             },
         },
         # Other issues
-        '#jp-top-panel, #jp-bottom-panel, #jp-menu-panel': {'color': 'inherit'},
-        '.CodeMirror': {
+        '<#jp-top-panel, #jp-bottom-panel, #jp-menu-panel': {'color': 'inherit'},
+        '<.CodeMirror': {
             'padding-bottom':'8px !important',
             'padding-right':'8px !important',
         }, # Jupyter-Lab make space in input cell
-        '.cell-output-ipywidget-background': { # VSCode issue */
+        '<.cell-output-ipywidget-background': { # VSCode issue */
             'background': 'var(--theme-background,inherit) !important',
             'margin': '8px 0px',
         },
-        '.NotesView': {
-            'background':'var(--secondary-bg) !important',
-            'padding':'8px !important',
+        '<.NotesView': {
+            'padding':'4px !important',
             'margin-top':'4px !important', # Avoid overlap with slides
+            'border-left':'2px solid gray !important', # neutral color
         },
-        '.jp-LinkedOutputView': {
-            '.SlidesWrapper': {
-                'display': 'none !important', # Double Display does not work properly
+        '.InView-Btn': {'display': 'none !important',},
+        '<.jp-LinkedOutputView': {
+            '.SlidesWrapper, .DisplayBox': {
+                'width': '100% !important',
+                'height': '100% !important',
+                'min-width': '100% !important',
+                'min-height': '100% !important',
+                'box-sizing': 'border-box !important', 
+                '.InView-Btn': {
+                    'display': 'block !important',
+                    'position': 'absolute',
+                    'top': '0',
+                    'left': '0',
+                    'z-index':'10',
+                    'color': 'white !important',
+                    'background': 'green !important',
+                    'font-size': '14px !important', # Avoid this button font scaling
+                },
+                '.Height-Dd, .Width-Slider': {'display': 'none !important',},
             },
             '.NotesView': {
-                'display': 'block !important', 
-                'box-sizing': 'border-box',
-                '^:before': {
-                    'content': '"Multiple views of slides do not behave properly, you can use this area for notes though!"',
-                    'display': 'block !important',
-                    'color': 'var(--secondary-fg)',
-                },
+                'display': 'none !important', 
             },   
         },
-        '#ipython-main-app .SlidesWrapper .output_scroll': { # For classic Notebook output
+        '<#ipython-main-app .SlidesWrapper .output_scroll': { # For classic Notebook output
             'height': 'unset !important',
             '-webkit-box-shadow': 'none !important',
             'box-shadow': 'none !important',
@@ -583,27 +637,28 @@ def layout_css(breakpoint, accent_color, show_laser_pointer = False): # Defult i
     })
 
 def viewport_css():
-    return '''
-    html, body, .jp-LabShell {
+    uclass = get_unique_css_class()
+    return f'''
+    html, body, .jp-LabShell {{
     position: fixed;
     left:0;
     top:0;
     width:0 !important;
     min-width: 0 !important; /* This is necessary for lab shell*/
     height:100vh !important;
-    }
-    .SlidesWrapper {
+    }}
+    {uclass}.SlidesWrapper {{
         position: fixed;
         left: 0;
         top:0;
         width:100vw !important;
         height:100vh !important;
-    }
-    #menubar-container { display: none !important; } /* For classic Notebook */
-    body[data-kaggle-source-type] .jp-Notebook { /* For Kaggle */
+    }}
+    #menubar-container {{ display: none !important; }} /* For classic Notebook */
+    body[data-kaggle-source-type] .jp-Notebook {{ /* For Kaggle */
         min-width: 0 !important;
         padding-right: 100vw !important;
-    }
+    }}
     '''
 
 def zoom_hover_css():
@@ -611,7 +666,7 @@ def zoom_hover_css():
         # Matplotlib by plt.show, self zoom, child zoom, plotly
         _zoom_ables: {
             '^:hover, ^:focus': {
-                'cursor': 'default', # Ovverride zoom-in cursor form main layout
+                'cursor': 'auto', # Ovverride zoom-in cursor form main layout
                 'position': 'fixed',
                 'backdrop-filter': 'blur(200px)',
                 'left':'50px',
@@ -651,7 +706,8 @@ def zoom_hover_css():
         
 
 def glass_css(opacity = 0.75,blur_radius = 50):
-    return f'''.BackLayer, .BackLayer .Front {{
+    uclass = get_unique_css_class()
+    return f'''{uclass} .BackLayer, {uclass} .BackLayer .Front {{
         position: absolute !important;
         top:0 !important;
         left:0 !important;
@@ -661,7 +717,7 @@ def glass_css(opacity = 0.75,blur_radius = 50):
         overflow:hidden;
         margin:0;
     }}
-    .BackLayer img{{
+    {uclass} .BackLayer img{{
         position: absolute;
         left:0;
         top:0;
@@ -670,11 +726,11 @@ def glass_css(opacity = 0.75,blur_radius = 50):
         object-fit:cover;
         filter: blur({blur_radius}px);
     }}
-    .BackLayer .Front {{
+    {uclass} .BackLayer .Front {{
         background: var(--primary-bg);
         opacity:{opacity};
     }}
-    .BackLayer.jupyter-widgets-disconnected {{
+    {uclass} .BackLayer.jupyter-widgets-disconnected {{
         display:none;
     }}
     '''
\ No newline at end of file
