@@ -1,5 +1,5 @@
 """
-Author Notes: Classes in this module should only be instantiated in LiveSlide class or it's parent class
+Author Notes: Classes in this module should only be instantiated in Slides class or it's parent class
 and then provided to other classes via composition, not inheritance.
 """
 
@@ -27,7 +27,7 @@ class LayoutSettings:
         self._content_width = '90%' #Better
         self._code_lineno = True
         
-        self._slide_layout = Layout(height='auto',margin='auto',overflow='auto',padding='0.2em 2em')
+        self._slide_layout = Layout(height='auto',margin='auto',overflow='auto',padding='0.2em 2em') 
         self.width_slider  = self.widgets.sliders.width
         self.aspect_dd = self.widgets.ddowns.aspect
         self.scale_slider  = self.widgets.sliders.scale
@@ -43,6 +43,7 @@ class LayoutSettings:
         self._on_load_and_refresh() # First attempt of Javascript to work
         
         self.widgets.buttons.toc.on_click(self._toggle_tocbox)
+        self.widgets.buttons._inview.on_click(self.__block_post_run)
         self.theme_dd.observe(self._update_theme,names=['value'])
         self.scale_slider.observe(self._update_theme,names=['value'])
         self.aspect_dd.observe(self._update_size,names=['value'])
@@ -57,6 +58,15 @@ class LayoutSettings:
         self.set_code_style() #Trigger CSS in it, must
         self.set_layout(center = True) # Trigger this as well
         self._update_size(change = None) # Trigger this as well
+    
+    def __block_post_run(self,btn):
+        self.show_always(False)
+        self.widgets.navbox.children = [w for w in self.widgets.navbox.children if w is not btn] 
+        dh = getattr(self._slides._display_box, '_DH', None) # Get display handler
+        self._slides._display_box = self._slides._notes_view # Swap display box by just notes view
+        if dh is not None: 
+            dh.update(self._slides._display_box) # Update display box with just notes view
+        
         
     def _on_load_and_refresh(self): # on_displayed is not working in ipywidgets 8.0.0+
         self.__add_js()
@@ -79,30 +89,33 @@ class LayoutSettings:
         return f'{int(100*650/span)}px'
     
     def set(self, **kwargs):
-        """Add multiple settings at once. keys in kwargs should name of function after `set_` 
-        and values should be dictionary of arguments for that function. See examples below.
+        """Add multiple settings at once. keys in kwargs should be name of a function after `Slides.settings.set_` 
+        and values should be dictionary or tuple of arguments for that function. See examples below.
         ```python
         Slides.settings.set( 
             glassmorphic = dict(image_src='image_src'),
-            css = dict(css_dict={}),
+            css = ({},), # note trailing comma to make it tuple
             layout = dict(center=True, content_width='80%'),
         )
         ```
         """
         for k,v in kwargs.items():
-            if not isinstance(v,dict):
-                raise ValueError(f'values in kwargs should be dict, got {v!r}')
+            if not isinstance(v,(dict, tuple)):
+                raise TypeError(f'values in kwargs should be dict or tuple, got {v!r}')
             func = getattr(self,f'set_{k}', False)
             if func is False:
-                raise ValueError(f'No such function {k!r} in settings')
-            func(**v) # Call function with arguments
+                raise AttributeError(f'No such function {k!r} in settings')
+            func(**v) if isinstance(v, dict) else func(*v) # Call function with arguments
             
     
     def show_always(self, b: bool = True):
         """If True (default), slides are shown after each cell execution where a slide constructor is present (other view will be closed). 
-        Otherwise only when `slides.show()` is called or `slides` is the last line in a cell."""
+        Otherwise only when `slides.show()` is called or `slides` is the last line in a cell.
+        :::note
+            In JupyterLab, right click on the slides and select `Create New View for Output` and follow next step there to optimize display.
+        """
         if not isinstance(b, bool):
-            raise ValueError(f'Expected bool, got {b!r}')
+            raise TypeError(f'Expected bool, got {b!r}')
         self._slides._post_run_enabled = True if b else False # Do not rely on user if they really give bool or not
     
     def set_animation(self, main = 'slide_h',frame = 'slide_v'):
@@ -110,7 +123,7 @@ class LayoutSettings:
         if len(self._slides[:]) >= 1:
             self._slides[0]._set_overall_animation(main = main,frame = frame)
         else:
-            raise ValueError("No slides yet to set animation.")
+            raise RuntimeError("No slides yet to set animation.")
     
     @_sub_doc(colors = styles.theme_colors['Light'])
     def set_theme_colors(self, colors = {}):
@@ -134,7 +147,13 @@ class LayoutSettings:
         if len(self._slides[:]) >= 1:
             self._slides[0]._set_overall_css(css_dict = css_dict)
         else:
-            raise ValueError("No slides yet to set CSS.")
+            raise RuntimeError("No slides yet to set CSS.")
+        
+    def set_citation_mode(self, mode = 'global'):
+        "Set mode for citations form ['global', 'inline', 'footnote']."
+        if mode not in ['global', 'inline', 'footnote']:
+            raise ValueError(f'citation mode must be one of "global", "inline", "footnote" but got {mode}')
+        self._slides._citation_mode = mode
         
         
     def set_glassmorphic(self, image_src, opacity=0.85, blur_radius=50):
@@ -190,7 +209,7 @@ class LayoutSettings:
         elif text and isinstance(text,str):
             self._footer_kws['text'] = text #assign to text
         else:
-            raise ValueError(f'text should be string or None, not {type(text)}')
+            raise TypeError(f'text should be string or None, not {type(text)}')
         
         self._update_footer() # Update footer immediately
         
@@ -210,7 +229,7 @@ class LayoutSettings:
     def set_layout(self,center = True, content_width = None):
         "Central aligment of slide by default. If False, left-top aligned."
         self._content_width = content_width if content_width else self._content_width # user selected
-        style_dict = {'display':'block','width':content_width} #block is must
+        style_dict = {'display':'flex','width':content_width} #block is must
         if center:
             style_dict.update(dict(margin = 'auto',align_items = 'center',justify_content = 'center'))
         else: #container still should be in the center horizontally with auto margin
@@ -358,7 +377,12 @@ class LayoutSettings:
         else:
             self.btn_laser.icon = 'plus'
         # Update Layout CSS
-        self.widgets.htmls.main.value = html('style',_layout_css.layout_css(self.breakpoint, accent_color= self.colors['accent_color'], show_laser_pointer = self.btn_laser.value)).value
+        self.widgets.htmls.main.value = html('style',
+            _layout_css.layout_css(self.breakpoint, 
+                accent_color= self.colors['accent_color'], 
+                show_laser_pointer = self.btn_laser.value
+            )
+        ).value
     
     
     def _push_zoom(self,change):
