@@ -1,5 +1,5 @@
 """
-Author Notes: Classes in this module should only be instantiated in LiveSlide class or it's parent class
+Author Notes: Classes in this module should only be instantiated in Slides class or it's parent class
 and then provided to other classes via composition, not inheritance.
 """
 import os
@@ -8,10 +8,8 @@ import ipywidgets as ipw
 from IPython.display import display, Javascript
 from ipywidgets import HTML, FloatProgress, VBox, HBox, Box, GridBox, Layout, Button
 from . import styles, _layout_css
-from ..utils import html, _build_css
+from ..utils import html
 
-def _build_style_widget(css_dict):
-    return HTML(html('style',_build_css((), css_dict)).value)
 
 auto_layout =  Layout(width='auto')
 def describe(value): 
@@ -34,6 +32,7 @@ class _Buttons:
     pdf     = Button(description='Save PDF',layout= Layout(width='auto',height='auto'))
     png     = Button(description='Save PNG',layout= Layout(width='auto',height='auto'))
     cap_all = Button(description='Capture All',layout= Layout(width='auto',height='auto'))
+    _inview = Button(description='Click to Optimize Experience in JupyterLab',layout= Layout(width='auto',height='auto')).add_class('InView-Btn') # For testing if inside LinkedView
     
 @dataclass(frozen=True)
 class _Toggles:
@@ -69,7 +68,7 @@ class _Htmls:
     intro   = HTML().add_class('SidePanel-Text') # Intro HTML
     glass   = HTML().add_class('BackLayer') # For glass effect
     overlay = HTML().add_class('OverlayHtml') # For adding iframe of things
-
+    
 @dataclass(frozen=True)
 class _Inputs:
     """
@@ -118,54 +117,10 @@ class _Outputs:
 
 
 def _custom_progressbar(intslider):
-    "Retruns a progress bar with custom style html linked to the slider"
-    # This html should not be exposed to user
-    html = _build_style_widget({
-        '.NavWrapper': {
-            '^,^ > div': {
-                'padding': '0px',
-                'margin': '0px',
-                'overflow': 'hidden',
-                'max-width': '100%',
-            },
-            '.progress': {
-                'width': '100% !important',
-                'transform': 'translate(-2px,1px) !important',
-                '^, .progress-bar': {
-                    'border-radius': '0px',
-                    'margin': '0px',
-                    'padding': '0px',
-                    'height': '4px !important',
-                    'overflow': 'hidden',
-                    'left': '0px',
-                    'bottom': '0px',
-                },
-            },
-            '.widget-hprogress': {
-                'height': '4px !important',
-            },
-            '.NavBox': {
-                'z-index': '2',
-                'overflow': 'hidden',
-                '.Menu-Item': {
-                    'font-size': '18px !important',
-                    'overflow': 'hidden',
-                    'opacity': '0.4',
-                    'z-index': '3',
-                    '^:hover': {
-                        'opacity': '1',
-                    },
-                },
-                '.Footer p': {
-                    'font-size': '14px !important',
-                },
-            },
-        },
-    }) # Should be HTML Widget
+    "Retruns a progress bar linked to the slider"
     intprogress = FloatProgress(min=0, max=100,value=0, layout=Layout(width='100%'))
     ipw.link((intslider, 'value'), (intprogress, 'value')) # This link enable auto refresh from outside
-    
-    return intprogress, html
+    return intprogress
 
 def _notification(content,title='IPySlides Notification',timeout=5):
     _title = f'<b>🔔 {title}</b><br/>' if title else '' # better for inslides notification
@@ -198,7 +153,7 @@ def _notification(content,title='IPySlides Notification',timeout=5):
 
 class Widgets:
     """
-    Instantiate under `LiveSLides` class only and provide to other classes after built-up.
+    Instantiate under `Sides` class only and provide to other classes after built-up.
     """
     def __setattr__(self, name , value):
         if name in self.__dict__:
@@ -230,7 +185,7 @@ class Widgets:
         self.outputs = _Outputs()
         
         # Make the progress bar and link to slides
-        self.progressbar, self._proghtml = _custom_progressbar(self.sliders.progress)
+        self.progressbar = _custom_progressbar(self.sliders.progress)
         
         # Layouts build on these widgets
         self.controls = HBox([
@@ -248,9 +203,9 @@ class Widgets:
         ],layout=Layout(height='28px')).add_class('NavBox')
         
         self.navbox = VBox([
+            self.buttons._inview,
             self.footerbox,
             VBox([
-                self._proghtml,
                 self.progressbar
                 ])
         ]).add_class('NavWrapper')   #class is must
