@@ -11,7 +11,7 @@ import ipywidgets as ipw
 
 from .xmd import parse, extender as _extender
 from .source import Source
-from .writers import write, iwrite
+from .writer import write, iwrite
 from .formatters import bokeh2html, plt2html, highlight, _HTML, serializer, _fix_repr
 from . import utils
 
@@ -19,7 +19,7 @@ _under_slides = {k:getattr(utils,k,None) for k in utils.__all__}
 
 from ._base.base import BaseSlides
 from ._base.intro import logo_svg, key_combs
-from ._base.scripts import multi_slides_alert
+from ._base.scripts import clear_disconnected_slides
 from ._base.slide import Slide, _build_slide
 from ._base.icons import Icon as _Icon, loading_svg
 from .__version__ import __version__
@@ -85,18 +85,22 @@ class Slides(BaseSlides):
         self.source = Source # Code source
         self.icon = _Icon # Icon is useful to add many places
         self.write  = write 
-        self.iwrite = iwrite # will be discarded at some point
+        self.iwrite = iwrite
         self.parse = parse # Parse extended markdown
         self.serializer = serializer # Serialize IPython objects to HTML
         
-        self._remove_post_run_callback() # Remove post_run_cell callback
+        self._remove_post_run_callback() # Remove post_run_cell callback before this and at end
         self._post_run_enabled = True # Enable post_run_cell event than can be hold by skip_post_run_cell context manager
         with suppress(Exception): # Avoid error when using setuptools to install
             self.widgets._notebook_dir = self.shell.starting_dir # This is must after shell is defined
             self.shell.register_magic_function(self._slide, magic_kind='cell',magic_name='slide')
             self.shell.register_magic_function(self.__title, magic_kind='cell',magic_name='title')
             self.shell.register_magic_function(self.__xmd, magic_kind='line_cell',magic_name='xmd')
-            self.shell.user_ns['get_slides_instance'] = lambda: self
+            
+            def get_slides_instance(): # This will be pointed back from xmd as well
+                return self
+            
+            self.shell.user_ns['get_slides_instance'] = get_slides_instance
             
         # Override print function to display in order in slides
         if self.shell.__class__.__name__ in ('ZMQInteractiveShell','Shell'): # Shell for Colab
@@ -141,10 +145,11 @@ class Slides(BaseSlides):
         self.widgets.buttons.refresh.on_click(self._update_dynamic_content)
         
         # All Box of Slides
-        self._box =  self.widgets.mainbox 
+        self._box =  self.widgets.mainbox.add_class(self.uid)
         self._on_load_and_refresh() # Load and browser refresh handling
         self._display_box = None # Initialize
         self.set_overlay_url(url = None) # Set overlay url for initial information
+        self._remove_post_run_callback() # Remove post_run_cell callback at end of init, otherwise it appears during import
     
     @contextmanager
     def skip_post_run_cell(self):
@@ -172,17 +177,16 @@ class Slides(BaseSlides):
         if result.error_before_exec or result.error_in_exec:
             return # Do not display if there is an error
         if self._post_run_enabled:
-            return self.show() # Display after cell is executed only when enabled
+            return self._ipython_display_() # Display after cell is executed only when enabled, don call show here, make issues
                      
     
     def _on_load_and_refresh(self):
-        self.widgets._exec_js(multi_slides_alert)
+        self.widgets._exec_js(clear_disconnected_slides)
         if self._max_index == 0: # prevent overwrite
             self._add_clean_title()
             
         with suppress(BaseException): # Does not work everywhere.
             self.widgets.inputs.bbox.value = ', '.join(str(a) for a in self.screenshot.screen_bbox) # Useful for knowing scren size
-
     
     def __repr__(self):
         repr_all = ',\n    '.join(repr(s) for s in self._iterable)
@@ -262,7 +266,6 @@ class Slides(BaseSlides):
         if self.running is None:
             raise RuntimeError(error_msg or 'This operation is only allowed under slide constructor.')
     
-    
     def citations(self, func):
         """Decorator to get all citations as a tuple that can be passed to given `func` function. and update dynamically.
         `func` must accept a single argument which will be tuple of citations.
@@ -275,7 +278,7 @@ class Slides(BaseSlides):
                     
                 return func(tuple(sorted(_all_citations.values(), key=lambda x: int(x._id))))
 
-            raise ValueError("Citations are not writable in 'inline' or 'footnote' mode. They appear on slide automatically.")
+            raise RuntimeError("Citations are not writable in 'inline' or 'footnote' mode. They appear on slide automatically.")
         
         return self._dynamic_private(_citations_handler, tag = '_cited', hide_refresher = True)
     
@@ -287,7 +290,10 @@ class Slides(BaseSlides):
                     ::: align-center
                         color[teal]`Author: Abdul Saboor`
                         
-                        👈🏻 **Read more instructions in left panel**''',
+                        👈🏻 **Read more instructions in left panel**
+                    ::: note-tip
+                        In JupyterLab, right click on the slides and select `Create New View for Output` for optimized display.
+                    ''',
                 display_inline = True)  
                 self.details(self.parse(key_combs, display_inline = False), 'Keyboard Shortcuts').display()
                 
@@ -296,6 +302,7 @@ class Slides(BaseSlides):
     def clear(self):
         "Clear all slides. This will also clear resources including citations, sections."
         self._slides_dict = {} # Clear slides
+        _ = [self.__dict__.pop(s, None) for s in getattr(self, '_links_dict', {})] # clear slides attributes
         self.set_citations({}) # Clears citations from disk too
         self._next_number = 0 # Reset slide number to 0, because user will overwrite title page.
         self._add_clean_title() # Add clean title page without messing with resources.
@@ -360,7 +367,7 @@ class Slides(BaseSlides):
         
         if file is not None:
             if citations is not None:
-                raise ValueError('Cannot set citations from file and dictionary at the same time!')
+                raise RuntimeError('Cannot set citations from file and dictionary at the same time!')
             
             if isinstance(file, str):
                 self._set_citations_from_file(file)
@@ -388,6 +395,7 @@ class Slides(BaseSlides):
         self.verify_running('Sections can be added only inside a slide constructor!')
         
         self.running._section = text # assign before updating toc
+        self.running._sec_id = f's-{id(self.running)}' # Must for enabling links in export
         
         for s in self[:]:
             if getattr(s, '_toced', False) and s != self.running: # self will be built of course at end
@@ -396,22 +404,25 @@ class Slides(BaseSlides):
     def toc(self, func):
         """Decorator to add dynamic table of contents to slides which get updated on each new section and refresh/update_display.
         `func` should take one argument which is the tuple of sections."""
+        def fmt_sec(slide):
+            return f'<a href="#{slide._sec_id}" class="export-only">{slide._section}</a><span class="jupyter-only">{slide._section}</span>'
+        
         def _toc_handler():
             sections = []
             this_index = self[:].index(self.running) if self.running in self[:] else self.running.number # Monkey patching index, would work on next run
             for slide in self[:this_index]:
                 if slide._section:
-                    sections.append(self.html('div', slide._section, style='',className='toc-item prev'))
+                    sections.append(self.html('div', fmt_sec(slide), style='',className='toc-item prev'))
 
             if self.running._section:
-                sections.append(self.html('div', self.running._section, style='',className='toc-item this'))
+                sections.append(self.html('div', fmt_sec(self.running), style='',className='toc-item this'))
                 
             elif sections:
                 sections[-1] = _HTML(sections[-1].value.replace('toc-item prev','toc-item this'))
 
             for slide in self[this_index+1:]:
                 if slide._section:
-                    sections.append(self.html('div', slide._section, style='',className='toc-item next'))
+                    sections.append(self.html('div', fmt_sec(slide), style='',className='toc-item next'))
             
             return func(tuple(sections))
            
@@ -463,15 +474,14 @@ class Slides(BaseSlides):
         if self.shell is None or self.shell.__class__.__name__ == 'TerminalInteractiveShell':
             raise Exception('Python/IPython REPL cannot show slides. Use IPython notebook instead.')
         
-        # This is useful for readily available objects with slides instead of indexing.
-        self.__dict__.update({f's{item.label}'.replace('.','_'): item for item in self._iterable if item.label})
-        
         self._remove_post_run_callback() # Avoid duplicate display
         self._update_toc() # Update toc before displaying app to include all sections
         self._update_dynamic_content() # Update dynamic content before displaying app
         self.close_view() # Close previous views
-        self._display_box = ipw.VBox(children=[self._box,self._notes_view]) # Initialize display box again
-        return display(self._display_box) # Display slides
+        self.widgets.navbox.children = [self.widgets.buttons._inview, *self.widgets.navbox.children] # Important to add inview button for each new view
+        self._display_box = ipw.VBox(children=[self._box, self._notes_view]).add_class('DisplayBox') # Initialize display box again
+        h = display(self._display_box, display_id = True) # Display slides
+        self._display_box._DH = h # This is important for Jupyter Lab to optimize experience
     
     def close_view(self):
         "Close slides/cell view, but keep slides in memory than can be shown again."    
@@ -517,8 +527,9 @@ class Slides(BaseSlides):
     def _switch_slide(self,old_index, new_index): # this change is provide from _update_content
         self.widgets.outputs.slide.clear_output(wait=False) # Clear last slide CSS
         with self.widgets.outputs.slide:
-            self.html('style',f'''.TOC .toc-item.s{self._sectionindex} {{font-weight:bold;border-right: 4px solid var(--primary-fg);}}
-            .TOC .toc-item {{border-right: 4px solid var(--secondary-bg);}}'''
+            uclass = f'.{self.uid} .TOC'
+            self.html('style',f'''{uclass} .toc-item.s{self._sectionindex} {{font-weight:bold;border-right: 4px solid var(--primary-fg);}}
+            {uclass} .toc-item {{border-right: 4px solid var(--secondary-bg);}}'''
             ).display()
         
             if self.screenshot.capturing == False:
@@ -528,10 +539,10 @@ class Slides(BaseSlides):
         if (old_index + 1) > len(self.widgets.slidebox.children):
             old_index = new_index # Just safe
             
-        self.widgets.slidebox.children[old_index].layout = ipw.Layout(width = '0',margin='0',opacity='0') # Hide old slide
+        self.widgets.slidebox.children[old_index].layout = ipw.Layout(width = '0', height='100%',margin='0',opacity='0') # Hide old slide
         self.widgets.slidebox.children[old_index].remove_class('SlideArea')
         self.widgets.slidebox.children[new_index].add_class('SlideArea') # First show then set layout
-        self.widgets.slidebox.children[new_index].layout = self.settings._slide_layout 
+        self.widgets.slidebox.children[new_index].layout = self.settings._slide_layout
         
     def _update_content(self,change):
         if self.progress_slider.index == 0: # First slide
@@ -549,9 +560,8 @@ class Slides(BaseSlides):
             self.settings._update_footer(number_str = number) # Update footer privately
             
             self._switch_slide(old_index= change['old'], new_index= change['new']) 
-            # below two lines after switching
-            self.current.run_on_load() # Run on_load setup
-            
+            self.current.run_on_load() # Run on_load setup after switching slide
+           
             
     def refresh(self): 
         "Auto Refresh whenever you create new slide or you can force refresh it"
@@ -559,30 +569,34 @@ class Slides(BaseSlides):
         if not self._iterable:
             self.progress_slider.options = [('0',0)] # Clear options
             self.widgets.slidebox.children = [] # Clear older slides
+            _ = [self.__dict__.pop(s, None) for s in getattr(self, '_links_dict', {})] # clear slides attributes
             return None
         
         n_last = float(self._iterable[-1].label)
         self._nslides = int(n_last) # Avoid frames number
         self._max_index = len(self._iterable) - 1 # This includes all frames
-        self.notify('Refreshing display of slides...')
+        
         # Now update progress bar
         opts = [(s.label, round(100*float(s.label)/(n_last or 1), 2)) for s in self._iterable]
         self.progress_slider.options = opts  # update options
         # Update Slides
         self.widgets.slidebox.children = [it._widget for it in self._iterable]
         for i, s in enumerate(self._iterable):
-            s.update_display() 
             s._index = i # Update index
-            self._slideindex = i # goto there to update display
+            
+        self._update_dynamic_content(None) # Update dynamic content including widgets
         
-        self._slideindex = 0 # goto first slide after refresh
+        # This is useful for readily available objects with slides instead of indexing.
+        old_links = getattr(self,'_links_dict', {})
+        _ = [self.__dict__.pop(s, None) for s in old_links] # Remove old links
+        self._links_dict = {f's{item.label}'.replace('.','_'): item for item in self._iterable if item.label}
+        self.__dict__.update(self._links_dict) # Add new links      
     
-     
     def proxy(self,text):
         """Place a proxy placeholder in your slide and returns it's `handle`. This is useful when you want to update the placeholder later.
         Use `Slides.proxies[index].capture` or `handle.capture` contextmanager to update the placeholder.
         """
-        self.verify_running('proxy placeholder can only be used inside a slide constructor.')
+        self.verify_running('proxy placeholder can only be used in a slide constructor!')
         return self.running._proxy_private(text)
     
     @property
@@ -612,7 +626,7 @@ class Slides(BaseSlides):
         """
         line = line.strip().split() #VSCode bug to inclue \r in line
         if line and not line[0].isnumeric():
-            raise ValueError(f'You should use %%slide integer >= 1 -m(optional), got {line}')
+            raise TypeError(f'You should use %%slide integer >= 1 -m(optional), got {line}')
         
         slide_number_str = line[0] # First argument is slide number
         
@@ -638,14 +652,13 @@ class Slides(BaseSlides):
         if not isinstance(slide_number, int):
             raise ValueError(f'slide_number should be int >= 1, got {slide_number}')
         
-        assert slide_number >= 0 # slides should be >= 1, zero for title slide
+        if slide_number < 0: # zero for title slide
+            raise ValueError(f'slide_number should be int >= 1, got {slide_number}')
         
         with _build_slide(self, f'{slide_number}') as s, self.source.context(auto_display = False, depth = 4) as c: # depth = 4 to source under context manager
             s.set_source(c.raw, 'python') # Update cell source befor yielding
             yield s # Useful to use later
         
-            
-        
     def __title(self,line,cell):
         "Turns to cell magic `title` to capture title"
         return self._slide('0 -m' if '-m' in line else '0',cell)
@@ -689,7 +702,7 @@ class Slides(BaseSlides):
                 if any([getattr(slide, attr, False) for attr in ('_has_widgets', '_toced', '_cited')]):
                     slide.update_display(go_there = False)
                 # Update dynamic content in slide
-                for dp in slide._dproxies.values():
+                for dp in slide._dproxies.values(): 
                     dp.update_display()
     
     def frames(self, slide_number, *objs, repeat = False, frame_height = 'auto'):
@@ -726,8 +739,9 @@ class Slides(BaseSlides):
             if not isinstance(slide_number,int):
                 return print(f'slide_number expects integer, got {slide_number!r}')
             
-            assert slide_number >= 0 # Should be >= 0
-
+            if slide_number < 0: # title slide is 0 
+                raise ValueError(f'slide_number should be >= 1, got {slide_number!r}')
+            
             if repeat == True:
                 _new_objs = [objs[:i] for i in range(1,len(objs)+1)]
             elif isinstance(repeat,(list, tuple)):
@@ -773,7 +787,7 @@ class Slides(BaseSlides):
             
             # Update All displays
             for s in this_slide._frames:
-                s.update_display()
+                s.update_display() # This call is much important, otherwise content of many slides do not show
                 # Remove duplicate sections/notes if any
                 if s._section == this_slide._section:
                     s._section = None
@@ -837,7 +851,7 @@ class Slides(BaseSlides):
         self.widgets.tocbox.children = children
         
     def create(self, *slide_numbers):
-        "Create empty slides with given slide numbers. If a slide already exists, it remains same. This is faster than creating one slide each time."
+        "Create empty slides with given slide numbers. If a slide already exists, it remains same. This is much faster than creating one slide each time."
         new_slides = False
         for slide_number in slide_numbers:
             if f'{slide_number}' not in self._slides_dict:
@@ -868,8 +882,7 @@ class Slides(BaseSlides):
         Use `auto.title`, `auto.slide` contextmanagers, `auto.frames` decorator and `auto.from_markdown` 
         function without thinking about what should be slide number.
         """
-        last_hist = list(self.shell.history_manager.get_range())[-1][-1]
-        if re.findall(r'AutoSlides\(|AutoSlides\s+\(', last_hist):
+        if self._called_from_notenook('AutoSlides'):
             return None
         
         auto = namedtuple('AutoSlides',['title','slide','frames','from_markdown'])
@@ -898,7 +911,9 @@ class Slides(BaseSlides):
             
             _html = self.html('div',[self.html('span',url), self.iframe(url,height='100%')])
             self.widgets.htmls.overlay.value= _html.value
-            self.settings.btn_overlay.value = True # Bring there when something is available
+               
+            if self._called_from_notenook('set_overlay_url') and not getattr(self.current,'_on_load',None):
+                self.settings.btn_overlay.value = True # Do not open panel during presentation by on_load function, otherwise immediately open it
             
         elif url is None:
             _html = self.html('div',[
@@ -909,7 +924,7 @@ class Slides(BaseSlides):
                 ])
             self.widgets.htmls.overlay.value= _html.value # Set overlay to blank and give docs info
         else:
-            raise ValueError(f'url must be a valide string or None, got {url!r}')
+            raise TypeError(f'url must be a valide string or None, got {url!r}')
     
         
 # Make available as Singleton Slides
@@ -934,6 +949,8 @@ class Slides:
         - Run `slides.demo()` to see a demo of some features.
         - Run `slides.docs()` to see documentation.
         - Instructions in left settings panel are always on your fingertips.
+        - Creating slides in a batch using `Slides.create` is much faster than adding them one by one.
+        - In JupyterLab, right click on the slides and select `Create New View for Output` for optimized display.
     
    """)
     def __new__(cls,
@@ -956,21 +973,17 @@ class Slides:
                 ):
         "Returns Same instance each time after applying given settings. Encapsulation."
         _private_instance.__doc__ = cls.__doc__ # copy docstring
-        
-        if citation_mode not in ['global', 'inline', 'footnote']:
-            raise ValueError(f'citation_mode must be one of "global", "inline", "footnote" but got {citation_mode}')
-        
         _private_instance.extender.extend(extensions)
-        _private_instance._citation_mode = citation_mode
         _private_instance.settings.show_always(show_always)
         
         _private_instance.settings.set(
-            layout      = dict(center = center, content_width = content_width),
-            footer      = dict(text = footer_text, show_date = show_date, show_slideno = show_slideno),
-            logo        = dict(src = logo_src,width = 60),
-            font_scale  = dict(font_scale = font_scale),
-            font_family = dict(text_font = text_font, code_font = code_font),
-            code_style  = dict(style = code_style, lineno = code_lineno),
+            citation_mode = dict(mode = citation_mode),
+            layout        = dict(center = center, content_width = content_width),
+            footer        = dict(text = footer_text, show_date = show_date, show_slideno = show_slideno),
+            logo          = dict(src = logo_src,width = 60),
+            font_scale    = dict(font_scale = font_scale),
+            font_family   = dict(text_font = text_font, code_font = code_font),
+            code_style    = dict(style = code_style, lineno = code_lineno),
         )
         
         with suppress(BaseException): # Avoid error if no slides exist
