@@ -1,5 +1,5 @@
-__all__ = ['bullets','suppress_output','suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
-            'image','svg','iframe', 'format_html','format_css','alert','color','keep_format', 'run_doc',
+__all__ = ['alt','alert', 'color', 'bullets','suppress_output','suppress_stdout','details', 'set_dir', 'textbox', 'vspace', 'center',
+            'image','svg','iframe', 'format_html','format_css','keep_format', 'run_doc',
             'raw','enable_zoom','html','sig','doc','code','today','sub','sup']
 __all__.extend(['rows','cols','block','classed'])
 __all__.extend([f'block_{c}' for c in 'rgbycma'])
@@ -19,6 +19,7 @@ from IPython.utils.capture import capture_output
 import ipywidgets as ipw
 
 from .formatters import fix_ipy_image, _HTML, _fix_repr
+from .xmd import get_unique_css_class
 
 def _fmt_cols(*objs,widths = None):
     if not widths and len(objs) >= 1:
@@ -48,6 +49,7 @@ _css_docstring = """`css_dict` is a nested dict of css selectors and properties.
 
 - All nested selectors are joined with space, so '.A': {'.B': ... } becomes '.A .B {...}' in CSS.
 - A '^' in start of a selector joins to parent selector without space, so '.A': {'^:hover': ...} becomes '.A:hover {...}' in CSS. You can also use '.A:hover' directly but it will restrict other nested keys to hover only.
+- A '<' in start of a nested selector makes it root selector, so '.A': {'<.B': ...} becomes '.A {}\n.B {...}' in CSS.
 - A '+' in start of a key allows using same key in dict for CSS fallback, so '.A': {'font-size': '20px','+font-size': '2em'} becomes '.A {font-size: 20px; font-size: 2em;}' in CSS.
 
 Read about specificity of CSS selectors [here](https://developer.mozilla.org/en-US/docs/Web/CSS/Specificity).
@@ -186,7 +188,7 @@ def format_html(*objs,widths=None):
 def _validate_key(key):
     "Validate key for CSS,allow only string or tuple of strings. commas are allowed only in :is(.A,#B),:has(.A,#B) etc."
     if not isinstance(key,str):
-        raise ValueError(f'key should be string, got {key!r}')
+        raise TypeError(f'key should be string, got {key!r}')
 
     if ',' in key:
         all_matches = re.findall(r'\((.*?)\)',key,flags=re.DOTALL)
@@ -213,7 +215,9 @@ def _build_css(selector, data):
         content += "\n}\n"
 
     for key, value in children:
-        if key.startswith('@media'): # Media query can be inside a selector and will be
+        if key.startswith('<'): # Make it root level
+            content += _build_css((key.lstrip('<'),), value)
+        elif key.startswith('@media') or key.startswith('@container'): # Media query can be inside a selector and will go outside
             content += f"{key} {{\n\t"
             content += _build_css(selector, value).replace('\n','\n\t').rstrip('\t') # last tab is bad
             content += "}\n"
@@ -237,23 +241,44 @@ def _build_css(selector, data):
     return content
 
 def _format_css(css_dict, allow_root_attrs = False):
+    uclass = get_unique_css_class()
     _all_css = '' # All css
     root_attrs = {k:v for k,v in css_dict.items() if not isinstance(v,dict)}
     if allow_root_attrs:
         if root_attrs:
             attrs_str = '\n'.join(f'\t{k} : {v};' for k,v in root_attrs.items())
-            _all_css += f'\n.SlidesWrapper, .BackLayer .Front {{\n{attrs_str}\n}}' # Set background for slide
+            _all_css += f'\n{uclass}.SlidesWrapper, {uclass} .BackLayer .Front {{\n{attrs_str}\n}}' # Set background for slide
     if root_attrs and not allow_root_attrs:
         print(f'Skipping attributes: \n{root_attrs}\nat root level of css_dict!')
     
     css_dict = {k:v for k,v in css_dict.items() if isinstance(v,dict)} # Remove root attrs after they are set above for background, no more use
-    _all_css += _build_css(('.SlideArea',),css_dict) # Build css from dict
+    _all_css += _build_css((f'{uclass} .SlideArea',),css_dict) # Build css from dict
     return html('style', _all_css)
     
 @_sub_doc(css_docstring = _css_docstring)
 def format_css(css_dict):
     "{css_docstring}"
     return _format_css(css_dict, allow_root_attrs = False)
+
+def alt(widget, obj):
+    "Display `widget` for slides and `obj` will be and displayed only in exported formats as HTML."
+    if not isinstance(widget, ipw.DOMWidget):
+        raise TypeError(f'widget should be a widget, got {widget!r}')
+    if isinstance(obj, ipw.DOMWidget):
+        raise TypeError(f'obj should not be a widget, got {obj!r}')
+    class Alt:
+        def __init__(self, widget, obj):
+            self._widget = widget
+            self._obj = obj
+            
+        def _ipython_display_(self):
+            return self.display()
+            
+        def display(self):
+            display(widget, metadata = {'DOMWidget': '---'})
+            display(_HTML(f'<div class="export-only">{_fix_repr(obj)}</div>')) # Hide from slides
+         
+    return Alt(widget, obj)
         
 def details(str_html,summary='Click to show content'):
     "Show/Hide Content in collapsed html."
@@ -296,29 +321,29 @@ def iframe(src, width='100%',height='auto',**kwargs):
     return _HTML(f._repr_html_())
 
 def enable_zoom(obj):
-    "Wraps are given obj in a parent with 'zoom-child' class, whether a widget or html/IPYthon object"
-    try:
-        return ipw.Box([obj]).add_class('zoom-child')
-    except:
+    "Wraps a given obj in a parent with 'zoom-child' class or add 'zoom-self' to widget, whether a widget or html/IPYthon object"
+    if isinstance(obj,ipw.DOMWidget):
+        return obj.add_class('zoom-self')
+    else:
         return classed(obj, 'zoom-child')
     
 def classed(obj, className):
     "Add a class to a given object, whether a widget or html/IPYthon object and pass to `write` command."
     if not isinstance(className,str):
-        raise ValueError('className must be a string!')
+        raise TypeError('className must be a string!')
     if isinstance(obj,(str,bytes)):
-        raise ValueError('Cannnot add class to strings/bytes! Use `::: className [indented block on new line]` pattern in markdown instead.')
-    try:
-        ipw.Box([obj]) # If this get success, it means obj is a widget
+        raise TypeError('Cannnot add class to strings/bytes! Use `::: className [indented block on new line]` pattern in markdown instead.')
+    
+    if isinstance(obj,ipw.DOMWidget):
         return obj.add_class(className)
-    except:
+    else:
         return _HTML(f'<div class="{className}">{_fix_repr(obj)}</div>')
 
 def center(obj):
     "Align a given object at center horizontally, whether a widget or html/IPYthon object"
-    try:
-        return ipw.Box([obj]).add_class('align-center')
-    except:
+    if isinstance(obj,ipw.DOMWidget):
+        return ipw.Box([obj]).add_class('align-center') # needs to wrap in another for cenering
+    else:
         return _HTML(f'<div class="align-center">{_fix_repr(obj)}</div>')
     
 def html(tag, children = None,className = None,**node_attrs):
@@ -339,7 +364,7 @@ def html(tag, children = None,className = None,**node_attrs):
         return _HTML(f'<hr/>') # Special case for hr
     
     if children and tag.endswith('/'):
-        raise ValueError(f'Parametr `children` should be None for self closing tag {tag!r}')
+        raise RuntimeError(f'Parametr `children` should be None for self closing tag {tag!r}')
     
     if tag == 'style':
         node_attrs = {} # Ignore node_attrs for style tag
@@ -360,7 +385,7 @@ def html(tag, children = None,className = None,**node_attrs):
     elif isinstance(children,(list,tuple)):
         content = '\n'.join(_fix_repr(child) for child in children) # Convert to html nodes in sequence of rows
     else:
-        raise ValueError(f'Children should be a list/tuple of objects or str, not {type(children)}')
+        raise TypeError(f'Children should be a list/tuple of objects or str, not {type(children)}')
         
     tag_in =  f'<{tag} {attrs}>' if attrs else f'<{tag}>' # space is must after tag, strip attrs spaces
     return _HTML(f'{tag_in}{content}</{tag}>')
@@ -386,7 +411,7 @@ def color(text,fg='blue',bg=None):
     return _HTML(f"<span style='background:{bg};color:{fg};padding: 0.1em;border-radius:0.1em;'>{text}</span>")
 
 def keep_format(plaintext_or_html):
-    "Bypasses from being parsed by markdown parser. Useful for some graphs, e.g. keep_raw(obj.to_html()) preserves its actual form."
+    "Bypasses from being parsed by markdown parser. Useful for some graphs, e.g. keep_format(obj.to_html()) preserves its actual form."
     if not isinstance(plaintext_or_html,str):
         return plaintext_or_html # if not string, return as is
     return _HTML(plaintext_or_html) 
